|logo|

|build_status| |documentation_status|
|codecov|
|requirements|


Markdownreveal
==============

This tool allows you to create and visualize presentations with simple
Markdown notation. It is based on reveal.js and is able to generate the
required HTML and refresh your browser view for easier and faster
presentation creation. Documentation can be found at the
`official website <https://markdownreveal.readthedocs.io/>`_.

You can also have a look at our
`online presentation example <https://markdownreveal.github.io/example/>`_ and
`its corresponding source code <https://github.com/markdownreveal/example>`_.


.. |logo|
   image:: docs/source/logo/logo.png
      :width: 100px
      :target: https://markdownreveal.readthedocs.io/
.. |build_status|
   image:: https://api.travis-ci.org/markdownreveal/markdownreveal.svg?branch=master
      :target: https://travis-ci.org/markdownreveal/markdownreveal
.. |documentation_status|
   image:: https://readthedocs.org/projects/markdownreveal/badge/
      :target: https://markdownreveal.readthedocs.io/
.. |codecov| image:: https://codecov.io/github/markdownreveal/markdownreveal/coverage.svg?branch=master
   :target: https://codecov.io/github/markdownreveal/markdownreveal
   :alt: Coverage (codecov) badge
.. |requirements| image:: https://requires.io/github/markdownreveal/markdownreveal/requirements.svg
   :target: https://requires.io/github/markdownreveal/markdownreveal/requirements/
   :alt: Requirements badge
